@@ -38,7 +38,7 @@ no warnings;
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
-$VERSION = '0.79'; # our $VERSION = '';
+$VERSION = '0.81'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -92,6 +92,7 @@ sub descend
   my $countcase = $d{countcase}; say $tee "IN ENTRY DESCEND \$countcase : " . dump( $countcase );
   my $countblock = $d{countblock}; say $tee "IN ENTRY DESCEND \$countblock : " . dump( $countblock );
   my %dirfiles = %{ $d{dirfiles} };
+  say $tee "IN ENTRY DESCEND \$dirfiles{c} : " . dump( $dirfiles{c} );
   my %datastruc = %{ $d{datastruc} }; ######
   my @varnumbers = @{ $d{varnumbers} }; #say $tee "IN ENTRY DESCEND \@varnumbers : " . dump( @varnumbers );
   @varnumbers = Sim::OPT::washn( @varnumbers ); #say $tee "IN ENTRY DESCEND WASHED \@varnumbers : " . dump( @varnumbers );
@@ -125,15 +126,17 @@ sub descend
 
   if ( $direction eq "" )
   {
-    $direction = $dowhat{newdirection};
+    #$direction = $dowhat{newdirection};
+    $direction = ${$dowhat{direction}}[0][0];
   }
 
   if ( $starorder eq "" )
   {
-    $starorder = $dowhat{newstarorder};
+    #$starorder = $dowhat{newstarorder};
+    $starorder = ${$dowhat{starorder}}[0][0];
   }
-  #say $tee "IN ENTRY DESCEND \$direction : " . dump( $direction ); #NEW
-  #say $tee "IN ENTRY DESCEND \$starorder : " . dump( $starorder ); #NEW
+  say $tee "IN ENTRY DESCEND \$direction : " . dump( $direction ); #NEW
+  say $tee "IN ENTRY DESCEND \$starorder : " . dump( $starorder ); #NEW
 
   my $precomputed = $dowhat{precomputed}; say $tee "IN DESCEND \$precomputed: " . dump($precomputed); #NEW
   my @takecolumns = @{ $dowhat{takecolumns} }; #NEW
@@ -179,7 +182,7 @@ sub descend
   my $orderedname = "$exitname" . "-ord";
   if ( $orderedname ne "" )
   {
-    $orderedfile = "$mypath/" . "$file" . "_" . "$orderedname" . ".csv";
+    $orderedfile = "$mypath/" . "$file" . "_" . "$orderedname" . ".csv";orderedfile
   }
   else
   {
@@ -237,15 +240,15 @@ sub descend
     exit(say $tee "#END RUN.");
   }
 
-
-  if ( not( -e $repfile ) ){ die; }; #say $tee " \$repfile " . dump($repfile);
+  say $tee " \$repfile " . dump($repfile);
+  if ( not( -e $repfile ) ){ die "There isn't \$repfile: $repfile"; };
 
 
   my $instance = $instances[0]; # THIS WOULD HAVE TO BE A LOOP HERE TO MIX ALL THE MERGECASES!!! ### ZZZ
 
   my %dat = %{$instance};
   my @winneritems = @{ $dat{winneritems} }; #say $tee " \@winneritems " . dump(@winneritems);
-  my $countvar = $dat{countvar}; #say $tee "IN DESCEND \$countvar " . dump( $countvar );
+  my $countvar = $dat{countvar}; #say $tee "IN DESCEND \$countv$dirfiles{c}ar " . dump( $countvar );
   my $countstep = $dat{countstep}; #say $tee "IN DESCEND \$countstep " . dump( $countstep );
   my $to = $dat{to};
   my $origin = $dat{origin};
@@ -738,6 +741,8 @@ sub descend
   sub takeoptima
   {
     my ( $sortmixed ) = @_;
+    say $tee "ENTRY TAKEOPTIMA: \$sortmixed: $sortmixed";
+    say $tee "ENTRY TAKEOPTIMA: \$direction: $direction";
 
     my @lines;
     if ( $searchname eq "no" )
@@ -756,11 +761,11 @@ sub descend
 
     if ( ( $direction eq ">" ) or ( ( $direction eq "star"  ) and ( $starorder eq ">"  ) ) )
     {
-      $winnerentry = $lines[0]; #say TOFILE "dump( IN SUB TAKEOPTIMA\$winnerentry): " . dump($winnerentry);
+      $winnerentry = $lines[0]; say $tee "DIRECTION > OR STAR IN SUB TAKEOPTIMA. \$winnerentry: " . dump($winnerentry);
     }
     elsif ( ( $direction eq "<" ) or ( ( $direction eq "star"  ) and ( $starorder eq "<"  ) ) )
     {
-      $winnerentry = $lines[-1];
+      $winnerentry = $lines[-1]; say $tee "DIRECTION < OR STAR IN SUB TAKEOPTIMA. \$winnerentry: " . dump($winnerentry);
     }
     elsif ( ( $direction eq "=" ) or ( ( $direction eq "star"  ) and ( $starorder eq "="  ) ) )
     {
@@ -819,11 +824,10 @@ sub descend
 
     if ( $countblock == $#blocks )
     {
-      if ( ( ( $dirfiles{starsign} eq "yes" ) and ( $dirfiles{d} == scalar( @{ $dirfiles{starpositions} } ) )
-              and ( $dirfiles{c} == scalar( @{ $dirfiles{dummyblockelts} } ) ) )
-            or ( ( $dirfiles{starsign} ne "yes" ) ) )
+      if ( $dirfiles{starsign} eq "yes" )
       {
-
+        #if ( $dirfiles{c} == $#blockelts )
+        #{
         open( TOTRES, "$totres" ) or die;
         my @lins = <TOTRES>;
         close TOTRES;
@@ -862,7 +866,7 @@ sub descend
         }
 
 
-        open( ORDRES, ">$ordres" ) or die;
+        open( ORDRES, ">>$ordres" ) or die;
 
         foreach my $lin ( @sorted )
         {
@@ -871,7 +875,7 @@ sub descend
         close ORDRES;
 
 
-        if ( ( scalar( @starpositions > 0) ) and ( $countstring ) )
+        if ( ( scalar( @starpositions ) > 0 ) and ( $countstring ) )
         {
           open( ORDRES, "$ordres" ) or die;
           my @ordlines = <ORDRES>;
@@ -925,7 +929,7 @@ sub descend
             }
 
 
-            open( ORDTOT, ">$ordtot" ) or die;
+            open( ORDTOT, ">>$ordtot" ) or die;
             foreach my $ln ( @sortedln )
             {
               print ORDTOT $ln;
@@ -956,7 +960,7 @@ sub descend
         if ( $starstring eq "" )
         {
           say "NOT DOING";
-          say RESPONSE "#Net number of instances: $netinstnum.\n" ;
+          say RESPONSE "#N 0et number of instances: $netinstnum.\n" ;
         }
         elsif ( $starstring ne "" )
         {
@@ -985,19 +989,10 @@ sub descend
         say RESPONSE "Last initialization level: " . dump( @miditers );
         say RESPONSE "Descent directions: " . dump( $dowhat{direction} );
 
-      }
+        {
+          ;#INSERT THE FUNCTION ON METAMODELS HERE
+        }
 
-
-      if ( $dirfiles{starsign} eq "yes" )
-      {
-        ;# COPY HERE THE FUNCTION BELOW
-      }
-
-
-
-      if ( ( $dirfiles{starsign} eq "yes" ) and ( $dirfiles{d} == scalar( @{ $dirfiles{starpositions} } ) )
-          and ( $dirfiles{c} == scalar( @{ $dirfiles{dummyblockelts} } ) ) )
-      {
         $countblock = 0;
         $countcase++; ####!!!
         $countstring++;
@@ -1006,9 +1001,16 @@ sub descend
         push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
         say $tee "#Leaving case $countcase. Beginning with case " . ( plus1( $countcase ) ) . ".";
 
-        @varnumbers = @{ dclone( \@{ $dowhat{varnumbershold} } ) };
+        @varnumbers = @{ dclone( $dirfiles{varnumbershold} ) };
+        @miditers = @{ dclone( $dirfiles{miditershold} ) };
         $dirfiles{starsign} = "no";
-        $countblock++; ### !!!
+
+        Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
+        miditers => \@miditers,  winneritems => \@winneritems,
+        dirfiles => \%dirfiles, varnumbers => \@varnumbers,
+        sweeps => \@sweeps, datastruc => \%datastruc, dowhat => \%dowhat ,
+        sourcesweeps => \@sourcesweeps, } );
+        #}
       }
       elsif ( $dirfiles{starsign} ne "yes" )
       {
@@ -1020,14 +1022,12 @@ sub descend
         push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
         say $tee "#Leaving case $countcase. Beginning with case " . ( plus1( $countcase ) ) . ".";
 
-        $countblock++; ### !!!
+        Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
+        miditers => \@miditers,  winneritems => \@winneritems,
+        dirfiles => \%dirfiles, varnumbers => \@varnumbers,
+        sweeps => \@sweeps, datastruc => \%datastruc, dowhat => \%dowhat ,
+        sourcesweeps => \@sourcesweeps, } );
       }
-
-      Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
-      miditers => \@miditers,  winneritems => \@winneritems,
-      dirfiles => \%dirfiles, varnumbers => \@varnumbers,
-      sweeps => \@sweeps, datastruc => \%datastruc, dowhat => \%dowhat ,
-      sourcesweeps => \@sourcesweeps, } )
     }
     elsif( $countblock < $#blocks )
     {
@@ -1039,131 +1039,159 @@ sub descend
       #say $tee "\@uplift : " . dump( @uplift );
       #say $tee "\@backvalues : " . dump( @backvalues );
       #say $tee "\@varnumbers : " . dump( @varnumbers );
-      #say $tee "\@sweeps : " . dump( @sweeps );
+      #say $tee "\@sweeps : " . @blockeltsdump( @sweeps );
       #say $tee "\%datastruc : " . dump( %datastruc );
       #say $tee "\%dowhat : " . dump( %dowhat );
 
+
       if ( $dirfiles{starsign} eq "yes" )
       {
-        if ( ( $dirfiles{d} == scalar( @{ $dirfiles{starpositions} } ) )
-          and ( $dirfiles{c} == scalar( @{ $dirfiles{dummyblockelts} } ) ) )
+        say $tee "HERE AGAIN?!";
+        say $tee "HERE \$dirfiles{c} : " . dump( $dirfiles{c} );
+        say $tee "HERE \$#blockelts : " . dump( $#blockelts );
+        #if ( $dirfiles{c} == $#blockelts )
+        #{
+        #say $tee "I AM IN";
+
+
+
+
+        if ( $dirfiles{metamodel} eq "yes" )
         {
-          if ( $dirfiles{metamodel} eq "yes" )
+          sub cleanres
           {
-            sub cleanres
+            open( ORDRES, "$_") or die;
+            my $cleanordres = $_ . "-cleaned.csv";
+            my @lines = <ORDRES>;
+            close ORDRES;
+
+            open( CLEANORDRES, ">>$cleanordres" ) or die;
+
+            foreach my $line ( @lines )
             {
-              open( ORDRES, "$_") or die;
-              my $cleanordres = $_ . "-cleaned.csv";
-              my @lines = <ORDRES>;
-              close ORDRES;
-
-              open( CLEANORDRES, ">$cleanordres" ) or die;
-
-              foreach my $line ( @lines )
-              {
-                $line =~ s/$mypath\/$file// ;
-                $line =~ s/^_// ;
-                $line =~ /(\d+)_-(\d+),(\d+)/ ;
-                $line =~ s/$2// ;
-                $line =~ s/_-// ;
-                print CLEANORDRES $line;
-              }
-              close CLEANORDRES;
-              return( $cleanordres );
-            };
-
-            sub prepareblank { ;};
-            sub jointwo { ;};
-            sub givename { ;};
-            sub writefile { ;};
-
-            my $cleanordres = cleanres( $ordres ); say $tee "IN TAKEOPTIMA1 \$cleanordres : " . dump( $cleanordres );
-            my @blank = @{ prepareblank( \%miditers ) };
-            my @prepared = @{ jointwo( $cleanordres, \@blank ) };
-            my ( $metafill ) = givename( $cleanordtot );
-            my $metafile = "$metafill" . "_meta.csv";
-            my $ordmeta = "$metafill" . "_ordmeta.csv";
-            writefile( $metafill, \@prepared );
-            Sim::OPT::Interlinear( $metafill );
-
-
-            open( METAFILE, "$metafile" ) or die;
-            my @totlines = <METAFILE>;
-            close METAFILE;
-
-
-            if ( ( $direction eq "<" ) or ( $starorder eq "<" ) )
-            {
-              @sorted = sort { (split( ',', $a))[ 0 ] <=> ( split( ',', $b))[ 0 ] } @totlines;
+              $line =~ s/$mypath\/$file// ;
+              $line =~ s/^_// ;
+              $line =~ /(\d+)_-(\d+),(\d+)/ ;
+              $line =~ s/$2// ;
+              $line =~ s/_-// ;
+              print CLEANORDRES $line;
             }
-            elsif ( ( $direction eq ">" ) or ( $starorder eq ">" ) )
-            {
-              @sorted = sort { (split( ',', $b))[ 0 ] <=> ( split( ',', $a))[ 0 ] } @totlines;
-            }
-
-
-            open( ORDMETA, ">$ordmeta" ) or die;
-            foreach my $ln ( @sorted )
-            {
-              print ORDMETA $ln;
-            }
-            close ORDMETA;
+            close CLEANORDRES;
+            return( $cleanordres );
           }
 
+          sub prepareblank { ;};
+          sub jointwo { ;};
+          sub givename { ;};
+          sub writefile { ;};
 
-          my @lines;
+          my $cleanordres = cleanres( $ordres ); say $tee "IN TAKEOPTIMA1 \$cleanordres : " . dump( $cleanordres );
+          my @blank = @{ prepareblank( \%miditers ) };
+          my @prepared = @{ jointwo( $cleanordres, \@blank ) };
+          my ( $metafill ) = givename( $cleanordtot );
+          my $metafile = "$metafill" . "_meta.csv";
+          my $ordmeta = "$metafill" . "_ordmeta.csv";
+          writefile( $metafill, \@prepared );
+          Sim::OPT::Interlinear( $metafill );
+
+
+          open( METAFILE, "$metafile" ) or die;
+          my @totlines = <METAFILE>;
+          close METAFILE;
+
+
+          if ( ( $direction eq "<" ) or ( $starorder eq "<" ) )
           {
-            open( ORDMETA, $ordmeta ) or die( "$!" );
-            @lines = <ORDMETA>;
-            close ORDMETA;
+            @sorted = sort { (split( ',', $a))[ 0 ] <=> ( split( ',', $b))[ 0 ] } @totlines;
           }
-          my $winnerentry;
-
-          if ( ( $direction eq ">$cleanordres" ) or ( ( $direction eq "star"  ) and ( $starorder eq ">"  ) ) )
+          elsif ( ( $direction eq ">" ) or ( $starorder eq ">" ) )
           {
-            $winnerentry = $lines[0]; #say TOFILE "dump( IN SUB TAKEOPTIMA\$winnerentry): " . dump($winnerentry);
+            @sorted = sort { (split( ',', $b))[ 0 ] <=> ( split( ',', $a))[ 0 ] } @totlines;
           }
-          elsif ( ( $direction eq "<" ) or ( ( $direction eq "star"  ) and ( $starorder eq "<"  ) ) )
+
+          open( ORDMETA, ">>$ordmeta" ) or die;
+          foreach my $ln ( @sorted )
           {
-            $winnerentry = $lines[-1];
+            print ORDMETA $ln;
           }
-          elsif ( ( $direction eq "=" ) or ( ( $direction eq "star"  ) and ( $starorder eq "="  ) ) )
-          {
-            my $half = ( int( scalar( @lines ) / 2 )  );
-            $countblock = 0;
-            $countcase++; ####!!!
-            $countstring++;
-            $dirfiles{countstring} = $countstring;
-
-            push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
-            say $tee "#Leaving case $countcase. Beginning with case " . ( plus1( $countcase ) ) . ".";      $winnerentry = $lines[ $half ];
-          }
-          chomp $winnerentry;
-
-
-
-          push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
-          say $tee "#Leaving case " . ( plus1( $countcase ) ) . ", block " . ( plus1( $countcase ) ) . ", and descending!";
-
-          @varnumbers = @{ dclone( \@{ $dowhat{varnumbershold} } ) };
-          $dirfiles{starsign} = "no";
-          $countblock++; ### !!!
+          close ORDMETA;
         }
+
+
+
+        my @lines;
+        if ( $dirfiles{metamodel} eq "yes" )
+        {
+          open( ORDMETA, $ordmeta ) or die( "$!" );
+          @lines = <ORDMETA>;
+          close ORDMETA;        #if ( $dirfiles{c} == $#blockelts )
+        #{
+        }
+        else
+        {
+          if ( $searchname eq "no" )
+          {
+            open( SORTMIXED, $sortmixed ) or die( "$!" );
+            @lines = <SORTMIXED>;
+            close SORTMIXED;
+          }
+          elsif ( $searchname eq "yes" )
+          {
+            open( ORDEREDFILE, $orderedfile ) or die( "$!" );
+            @lines = <ORDEREDFILE>;
+            close ORDEREDFILE;
+          }
+        }
+
+
+        my $winnerentry;
+
+        if ( ( $direction eq ">" ) or ( ( $direction eq "star"  ) and ( $starorder eq ">"  ) ) )
+        {
+          $winnerentry = $lines[0]; #say TOFILE "dump( IN SUB TAKEOPTIMA\$winnerentry): " . dump($winnerentry);
+        }
+        elsif ( ( $direction eq "<" ) or ( ( $direction eq "star"  ) and ( $starorder eq "<"  ) ) )
+        {
+          $winnerentry = $lines[-1];
+        }
+        elsif ( ( $direction eq "=" ) or ( ( $direction eq "star"  ) and ( $starorder eq "="  ) ) )
+        {
+          my $half = ( int( scalar( @lines ) / 2 )  );
+          $winnerentry = $lines[ $half ];
+        }
+        chomp $winnerentry;
+
+        push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "IN STARPATH TAKEOPTIMA->\@winneritems " . dump(@winneritems);
+        say $tee "#Leaving case " . ( plus1( $countcase ) ) . ", block " . ( plus1( $countcase ) ) . ", and descending!";
+
+        @varnumbers = @{ dclone( $dirfiles{varnumbershold} ) };
+        @miditers = @{ dclone( $dirfiles{miditershold} ) };
+        $dirfiles{starsign} = "no";
+
+        $countblock++; ### !!!
+
+        Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
+        miditers => \@miditers,  winneritems => \@winneritems,
+        dirfiles => \%dirfiles, varnumbers => \@varnumbers,
+        sweeps => \@sweeps, datastruc => \%datastruc, dowhat => \%dowhat,
+        sourcesweeps => \@sourcesweeps, } );
+        #}
       }
-      elsif ( $dirfiles{starsign} ne "yes" )
+      else
       {
-        push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
-        say $tee "NOT DONE.";
+        say $tee "NOW I SHOULD ACT.";
+        push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "IN NORMALPATH TAKEOPTIMA->\@winneritems " . dump(@winneritems);
+        say $tee "NOT STAR-DESCENDING.";
         say $tee "#Leaving case " . ( plus1( $countcase ) ) . ", block " . ( plus1( $countcase ) ) . ", and descending!";
 
         $countblock++; ### !!!
-      }
 
-      Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
-      miditers => \@miditers,  winneritems => \@winneritems,
-      dirfiles => \%dirfiles, varnumbers => \@varnumbers,
-      sweeps => \@sweeps, datastruc => \%datastruc, dowhat => \%dowhat,
-      sourcesweeps => \@sourcesweeps, } )
+        Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
+        miditers => \@miditers,  winneritems => \@winneritems,
+        dirfiles => \%dirfiles, varnumbers => \@varnumbers,
+        sweeps => \@sweeps, datastruc => \%datastruc, dowhat => \%dowhat,
+        sourcesweeps => \@sourcesweeps, } );
+      }
     }
   } # END SUB takeoptima
 
